#!/usr/bin/env ruby
=begin
/****************************************************************
**
** Qt tutorial 5
**
****************************************************************/
=end
require "qte"
include Qte
require "qpe"
include Qpe

class MyWidget  <  QVBox

def initialize( parent=nil, name="" )
     super (parent, name)

    quit = QPushButton.new( "Quit", self, "quit" )
    quit.setFont( QFont.new( "Times", 18, QFont::Bold ) )

    connect( quit, QSIGNAL("clicked()"), QPEApplication::qApp, "quit()" )

    lcd  = QLCDNumber.new( 2, self, "lcd" )

    slider = QSlider.new( 0,99,0,10,Horizontal, self, "slider" )
    slider.setRange( 0, 99 )
    slider.setValue( 0 )

    connect( slider, QSIGNAL("valueChanged(int)"), lcd, "display(int)" )
end
end

    a = QPEApplication.new( [$0]+ARGV )

    w = MyWidget.new
    a.showMainWidget( w )
    a.exec()

